@@ -1228,17 +1228,27 @@ void MainWindow::_toggleWindowState()
             sharedAfterHideWindow();
         } else {
             sharedPreOpenWindow();
-            if (KWindowEffects::isEffectAvailable(KWindowEffects::Slide)) {
-                KWindowEffects::slideWindow(windowHandle(), KWindowEffects::TopEdge);
+            if (!m_isWayland) {
+                slideWindow();
             }
 
             show();
+            if (m_isWayland) {
+                slideWindow();
+            }
 
             sharedAfterOpenWindow();
         }
     }
 }
 
+void MainWindow::slideWindow()
+{
+    if (KWindowEffects::isEffectAvailable(KWindowEffects::Slide)) {
+        KWindowEffects::slideWindow(windowHandle(), KWindowEffects::TopEdge);
+    }
+}
+
 #if HAVE_X11
 void MainWindow::kwinAssistToggleWindowState(bool visible)
 {
